"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MysqlTransaction = void 0;
const noomitransaction_1 = require("./noomitransaction");
const connectionmanager_1 = require("./connectionmanager");
/**
 * mysql 事务类
 */
class MysqlTransaction extends noomitransaction_1.NoomiTransaction {
    /**
     * 开始事务
     */
    async begin() {
        if (!this.connection) {
            this.connection = await connectionmanager_1.getConnection();
        }
        await new Promise((resolve, reject) => {
            this.connection.beginTransaction((err, conn) => {
                if (err) {
                    reject(err);
                }
                resolve(null);
            });
        });
    }
    /**
     * 事务提交
     */
    async commit() {
        await new Promise((resolve, reject) => {
            this.connection.commit((err) => {
                if (err) {
                    reject(err);
                }
                resolve(null);
            });
        });
    }
    /**
     * 事务回滚
     */
    async rollback() {
        await new Promise((resolve, reject) => {
            this.connection.rollback((err) => {
                if (err) {
                    reject(err);
                }
                resolve(null);
            });
        });
    }
}
exports.MysqlTransaction = MysqlTransaction;
//# sourceMappingURL=mysqltransaction.js.map