"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransactionAdvice = void 0;
const transactionmanager_1 = require("./transactionmanager");
const connectionmanager_1 = require("./connectionmanager");
/**
 * 事务通知
 */
class TransactionAdvice {
    /**
     * 事务方法调用前通知
     */
    async before() {
        let tr = await transactionmanager_1.TransactionManager.get(true);
        //connection 未初始化，初始化connection
        if (!tr.connection) {
            tr.connection = await connectionmanager_1.getConnection();
        }
        //调用数+1
        tr.invokeNum++;
        if (tr.isBegin) {
            return;
        }
        tr.isBegin = true;
        await tr.begin();
    }
    /**
     * 事务方法返回时通知
     */
    async afterReturn() {
        let tr = await transactionmanager_1.TransactionManager.get();
        if (!tr || !tr.isBegin) {
            return;
        }
        //当前id为事务头，进行提交
        if (--tr.invokeNum === 0) {
            await tr.commit();
            //删除事务
            transactionmanager_1.TransactionManager.del(tr);
            //释放连接
            await transactionmanager_1.TransactionManager.releaseConnection(tr);
        }
    }
    /**
     * 事务方法抛出异常时通知
     */
    async afterThrow() {
        let tr = await transactionmanager_1.TransactionManager.get();
        if (!tr || !tr.isBegin) {
            return;
        }
        if (tr) {
            //最外层rollback
            if (--tr.invokeNum === 0) {
                await tr.rollback();
                transactionmanager_1.TransactionManager.del(tr);
                //释放连接
                await transactionmanager_1.TransactionManager.releaseConnection(tr);
            }
        }
    }
}
exports.TransactionAdvice = TransactionAdvice;
//# sourceMappingURL=transactionadvice.js.map