"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseRoute = void 0;
const validator_1 = require("../../tools/validator");
const util_1 = require("../../tools/util");
const noomimodeltip_1 = require("../../locales/noomimodeltip");
const application_1 = require("../../tools/application");
/**
 * 路由基类
 * 可自动为路由类生成model(传入参数对象)，自带request和response对象
 * 建议所有路由继承此基类
 */
class BaseRoute {
    /**
     * 空校验
     * @oaram model         模型数据
     * @param methodName    方法名
     * @returns             校验异常信息
     */
    doNullCheck(model, methodName) {
        let fields = this.constructor['__nullCheckMap'].get(methodName);
        if (!fields) {
            return null;
        }
        for (let f of fields) {
            if (!validator_1.Validator.validate("nullable", model[f], null)) {
                return util_1.Util.compileString(noomimodeltip_1.NoomiModelTip[application_1.App.language]['nullable'], f);
            }
        }
    }
    /**
     * 为model设置值
     * @param data  数据对象(由浏览器/客户端传入的数据参数)
     * @returns     无异常null，否则返回异常字段集
     */
    setModel(data, methodName) {
        const mCls = this.constructor['__modelClass'];
        if (mCls) {
            let m;
            if (methodName) {
                //设置null check字段
                let nullArr = this.constructor['__nullCheckMap'].get(methodName);
                m = Reflect.construct(mCls, [nullArr]);
            }
            else {
                m = Reflect.construct(mCls, []);
            }
            Object.getOwnPropertyNames(data).forEach((item) => {
                m[item] = data[item];
            });
            let ctType = this.request.getHeader('content-type');
            //数据转换和校验，如果request content-type为application/json，则不进行转换
            if (!ctType || !ctType.startsWith('application/json')) {
                let r = m.__handle();
                if (r) {
                    throw new Error(JSON.stringify(r));
                }
            }
            this.model = m;
        }
        else {
            this.model = data;
        }
        return null;
    }
    /**
     * 设置request对象
     * @param req   request对象
     */
    setRequest(req) {
        this.request = req;
    }
    /**
     * 设置reponse对象
     * @param res   response对象
     */
    setResponse(res) {
        this.response = res;
    }
    /**
     * 增加nullcheck 方法
     * @param methodName    方法名
     * @param props         检测数组
     */
    static __setNullCheck(methodName, props) {
        if (!this.__nullCheckMap) {
            this.__nullCheckMap = new Map();
        }
        else if (this.__nullCheckMap.has(methodName)) { //已经存在
            return;
        }
        this.__nullCheckMap.set(methodName, props);
    }
}
exports.BaseRoute = BaseRoute;
/**
 * null属性检查{方法名:待检查属性map}
 */
BaseRoute.__nullCheckMap = new Map();
//# sourceMappingURL=baseroute.js.map