import { NoomiTransaction } from "./noomitransaction";
declare class TransactionManager {
    /**
     * transaction map，用于维护事务，键为事务id，值为事务对象
     */
    private static transactionMap;
    /**
     * transaction 实例名
     */
    private static transactionMdl;
    /**
     * 切点名
     */
    static pointcutId: string;
    /**
     * 切面名
     */
    static aspectName: string;
    /**
     * 隔离级 1read uncommited 2read commited 3repeatable read 4serializable
     */
    static isolationLevel: number;
    /**
     * 事务配置项
     */
    static transactionOption: any;
    /**
     * 事务注册map，键为事务类名，值为[methodName1,methodName2,...]
     */
    private static registTransactionMap;
    static init(cfg: any): void;
    /**
     * 注册事务，在addInstance时正式添加到aop
     * @param className     类名
     * @param methodName    方法名或方法名串，支持通配符"*"
     */
    static registTransaction(className: string, methodName: string | string[]): void;
    /**
     * 处理实例事务，用于把事务注册map的事务添加到事务aop
     * @param instanceName      实例名
     * @param className         类名
     */
    static handleInstanceTranstraction(instanceName: string, className: string): void;
    /**
     * 添加为事务
     * @param instance      实例 或 类
     * @param methodName    方法名
     */
    static addTransaction(instance: any, methodName: any): void;
    /**
     * 获取transaction
     * @param newOne    如果不存在，是否新建
     * @return          transacton
     */
    static get(newOne?: boolean): Promise<NoomiTransaction>;
    /**
     * 删除事务
     * @param tr    事务
     */
    static del(tr: NoomiTransaction): void;
    /**
     * 获取connection
     */
    static getConnection(id?: number): any;
    /**
     * 释放连接
     * @param tr
     */
    static releaseConnection(tr: NoomiTransaction): Promise<void>;
    /**
     * 解析实例配置文件
     * @param path      文件路径
     * @param mdlPath   模型路径
     */
    static parseFile(path: string): void;
    /**
     * 初始化transaction advice
     * @since 1.0.0
     */
    private static initAdvice;
}
export { TransactionManager };
