/**
 * 文件监听类型
 * @since 0.4.4
 */
export declare enum EWatcherType {
    STATIC = 1,
    DYNAMIC = 2
}
/**
 * file watch 类
 * 用于监听 静态文件或instance(动态)文件的改变
 * 静态文件改变后会更新web cache
 * instance文件改变后，更新实例工厂，仅对“注解类”实例有效
 * @since 0.4.4
 */
export declare class FileWatcher {
    /**
     * 监听目录map，键为路径，值为类型，类型包括static(静态)和dynamic(动态)
     */
    private static directoryMap;
    /**
     * 添加监听目录
     * @param path      目录路径
     * @param type      类型
     */
    static addDir(path: string, type: EWatcherType): void;
    /**
     * 删除监听目录
     * @param path      目录路径
     */
    static removeDir(path: string): void;
    /**
     * 监听静态资源目录
     * @param path  目录路径
     */
    private static watchStatic;
    /**
     * 监听动态资源目录
     * @param path  路径
     */
    private static watchDynamic;
    /**
     * 处理单个静态目录
     * @param path  监听目录
     */
    private static handleStaticRes;
}
