import { IFilterCfg } from "../tools/types";
import { HttpRequest } from "./httprequest";
import { HttpResponse } from "./httpresponse";
/**
 * web后置处理，对web请求结果进行再处理
 * 如果处理方法返回为null，则处理链不再继续处理
 */
declare class WebAfterHandler {
    /**
     * 过滤器实例数组
     */
    private static handlers;
    /**
     * 待添加的处理器map，键为类名，值为 {
                methodName:方法名,
                pattern:正则式或正则式数组,
                order:优先级
            }
     */
    private static registHandlerMap;
    /**
     * 注册过滤器
     * 当对应类添加到实例工厂时，进行过滤器添加
     * @param cfg   {
     *                  className:类名,
     *                  methodName:过滤器方法名,
     *                  pattern:过滤url的正则式或正则式数组,
     *                  order:优先级
     *              }
     * @since 1.0.0
     */
    static registHandler(cfg: IFilterCfg): void;
    /**
     * 处理实例过滤器
     * @param instanceName  实例名
     * @param className     类名
     * @since 1.0.0
     */
    static handleInstanceHandler(instanceName: string, className: string): void;
    /**
     * 获取过滤器链
     * @param url   资源url
     * @returns     filter数组
     */
    private static getHandlerChain;
    /**
     * 执行过滤器链
     * @param url       url路径
     * @param result    处理结果
     * @param request   request 对象
     * @param response  response 对象
     * @returns         处理结果进行方法链处理，返回最后的处理结果
     */
    static doChain(url: string, result: any, request: HttpRequest, response: HttpResponse): Promise<any>;
}
export { WebAfterHandler };
