/**
 * web 配置类
 * @remarks
 * 用于管理web配置参数
 */
export declare class WebConfig {
    /**
     * 配置项
     */
    static config: any;
    /**
     * 是否使用https
     */
    static useHttps: boolean;
    /**
     * 是否使用cache
     */
    static useServerCache: boolean;
    /**
     * https配置，useHttps为true时有效，包括：
     *  only_https:是否只采用https，如果为true，则不会启动http server，只启动https server
     *  key_file:私钥文件路径，相对于根目录
     *  cert_file:证书文件路径，相对与根目录
     */
    static httpsCfg: object;
    /**
     * 跨域设置
     */
    static cors: object;
    /**
     * 欢迎页面，访问根目录时跳转到该页面
     */
    static welcomePage: string;
    /**
     * 获取参数
     * @param name webconfig参数名
     */
    static get(name: string): any;
    /**
     * 初始化
     * @param config 参阅web.json配置
     */
    static init(config: any): void;
    /**
     * @exclude
     * 解析路由文件
     * @param path  文件路径
     * @param ns    命名空间，默认 /
     */
    static parseFile(path: string): void;
    /**
     * 设置异常页面
     * @param pages page配置数组[{code:http异常码,location:异常码对应页面地址(相对于项目根目录)}]
     */
    static setErrorPages(pages: Array<object>): void;
}
